@@ -34,19 +34,44 @@ class Client(object):
             workspaceId=workspaceId,
             replaceLocalhostString=replaceLocalhostString
         )
+
+    # SQL
     def use_saved_query(self, title):
         query = self.workspace.saved_query.get(title)
         return self.execute(query['sql'])
     def list_saved_query(self):
         return self.workspace.saved_query.list_title()
-    def list_file(self):
-        return self.workspace.file.list_absolute_path()
-    def get_binary(self, absolutePath):
-        return self.workspace.file.get_content(absolutePath)
-    def get_csv_wrapper(self, absolutePath):
-        return self.workspace.file.get_csv_wrapper(absolutePath)
-    def get_json_wrapper(self, absolutePath):
-        return self.workspace.file.get_json_wrapper(absolutePath)
     def execute(self, sql):
         cursor = self.workspace.statement.execute(sql);
         return cursor
+
+    # files
+    def list_file(self):
+        return self.workspace.file.list_absolute_path()
+    def get_binary(self, absolute_path):
+        return self.workspace.file.get_content(absolute_path)
+
+    # wrappers
+    def _get_csv_wrapper(self, absolute_path):
+        return self.workspace.file.get_csv_wrapper(absolute_path)
+    def _get_json_wrapper(self, absolute_path):
+        return self.workspace.file.get_json_wrapper(absolute_path)
+    def _get_image_wrapper(self, absolute_path):
+        return self.workspace.file.get_image_wrapper(absolute_path)
+    # csv
+    def get_csv(self, absolute_path):
+        return self._get_csv_wrapper(absolute_path).to_list()
+    def get_pandas_csv(self, absolute_path):
+        return self._get_csv_wrapper(absolute_path).to_pandas()
+
+    # json
+    def get_json(self, absolute_path):
+        return self._get_json_wrapper(absolute_path).to_json()
+    def get_pandas_json(self, absolute_path):
+        return self._get_json_wrapper(absolute_path).to_pandas()
+    
+    # image
+    def get_pil_image(self, absolute_path):
+        return self._get_image_wrapper(absolute_path).to_pil()
+    def get_np_image(self, absolute_path):
+        return self._get_image_wrapper(absolute_path).to_np()
